%define module	networkx

Name:		python-%{module}
Version:	1.11
Release:	%mkrel 2
Summary:	Python package for the study of complex networks
License:	BSD
Group:		Development/Python
Url:		http://networkx.github.io/
Source0:	http://pypi.python.org/packages/source/n/networkx/%{module}-%{version}.tar.gz
Source1:	https://github.com/networkx/documentation/blob/gh-pages/%{module}-%{version}/_downloads/networkx_reference.pdf
Source2:	https://github.com/networkx/documentation/blob/gh-pages/%{module}-%{version}/_downloads/networkx_tutorial.pdf
Source3:	https://github.com/networkx/documentation/blob/gh-pages/%{module}-%{version}/_downloads/networkx-documentation.zip
Patch0:		fix-sphinx-build.patch
BuildArch:	noarch
BuildRequires:	pythonegg(2)(setuptools)
BuildRequires:	pythonegg(2)(matplotlib)
BuildRequires:	pkgconfig(python2)
BuildRequires:	pythonegg(2)(decorator)
BuildRequires:	pythonegg(2)(pyparsing)
BuildRequires:	pythonegg(2)(six)
BuildRequires:	pythonegg(2)(nose)

Requires:	pythonegg(2)(pygraphviz)
Requires:	pythonegg(2)(matplotlib)
Recommends:	pythonegg(2)(pyparsing)
Recommends:	pythonegg(2)(numpy)
Recommends:	pythonegg(2)(scipy)
Recommends:	pythonegg(2)(pyyaml)

%description
NetworkX (NX) is a Python package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

Features:
* Includes standard graph-theoretic and statistical physics functions
* Easy exchange of network algorithms between applications, disciplines,
  and platforms
* Includes many classic graphs and synthetic networks
* Nodes and edges can be "anything" (e.g. time-series, text, images,
  XML records)
* Exploits existing code from high-quality legacy software in C, C++,
  Fortran, etc.
* Open source (encourages community input)
* Unit-tested

%package	doc
Summary:	Documentation for networkx
Group:		Documentation
BuildRequires:	pythonegg(2)(sphinx)
BuildRequires:	pythonegg(2)(sphinx-rtd-theme)
BuildRequires:	pythonegg(2)(numpydoc)
Requires:	%{name} = %{version}-%{release}

%description	doc
Documentation for networkx.

%package -n	python3-%{module}
Summary:	Python 3 package for the study of complex networks
Group:		Development/Python
BuildRequires:	pythonegg(3)(setuptools)
BuildRequires:	pythonegg(3)(matplotlib)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pythonegg(3)(decorator)
BuildRequires:	pythonegg(3)(pyparsing)
BuildRequires:	pythonegg(3)(six)
BuildRequires:	pythonegg(3)(nose)

Requires:	pythonegg(3)(matplotlib)
Recommends:	pythonegg(3)(pyparsing)
Recommends:	pythonegg(3)(numpy)
Recommends:	pythonegg(3)(scipy)
Recommends:	pythonegg(3)(pyyaml)

%description -n	python3-networkx
NetworkX is a Python 3 package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.


%prep
%setup -q -n %{module}-%{version}
%autopatch -p1

# Fix permissions
find examples -type f -perm /0111 | xargs chmod a-x

# Use the system python-decorator instead of the bundled version
sed -e '/          "networkx\.external.*",/d' \
    -e "/sys\.version >= '3'/,/^$/d" \
    -i setup.py
pushd networkx
  rm -fr external
  sed "/import networkx\.external/d" __init__.py > init.py
  touch -r __init__.py init.py
  mv -f init.py __init__.py
for f in utils/decorators.py utils/misc.py; do
  sed "s/networkx\.external\.//" $f > fixed.py
  touch -r $f fixed.py
  mv -f fixed.py $f
done
popd

# Avoid downloading the doc files while building
cp -pf %{SOURCE1} %{SOURCE2} %{SOURCE3} doc/source

cp -a . %{py3dir}

%build
%py2_build
PYTHONPATH=$PWD/build/lib make SPHINXBUILD=sphinx-build -C doc html

pushd %{py3dir}
%py3_build
popd


%install
pushd %{py3dir}
%py3_install
popd

%py2_install
mv %{buildroot}%{_docdir}/networkx-%{version} ./installed-docs
rm -f installed-docs/INSTALL.txt

# Fix permissions and binary paths
for f in `grep -FRl /usr/bin/env %{buildroot}%{python2_sitelib}`; do
  sed 's|/usr/bin/env python|%{_bindir}/python|' $f > $f.new
  touch -r $f $f.new
  chmod a+x $f.new
  mv -f $f.new $f
done

for f in `grep -FRl /usr/bin/env %{buildroot}%{python3_sitelib}`; do
  sed 's|/usr/bin/env python|%{_bindir}/python3|' $f > $f.new
  touch -r $f $f.new
  chmod a+x $f.new
  mv -f $f.new $f
done

%check
%define enable_tests 1
%if %{enable_tests}
mkdir site-packages
mv networkx site-packages
PYTHONPATH=$PWD/site-packages python -c "import networkx; networkx.test()"
%endif

%files
%doc installed-docs/*
%{python2_sitelib}/%{module}
%{python2_sitelib}/%{module}-%{version}-py%{python2_version}.egg-info

%files -n python3-%{module}
%doc installed-docs/*
%{python3_sitelib}/%{module}
%{python3_sitelib}/%{module}-%{version}-py%{python3_version}.egg-info

%files doc
%doc doc/build/html/*


%changelog
* Thu May 05 2016 philippem <philippem> 1.11-2.mga6
+ Revision: 1009629
- fix sphinx build

* Sun Jan 31 2016 daviddavid <daviddavid> 1.11-1.mga6
+ Revision: 929353
- new version: 1.11
- remove numpy patch

* Wed Dec 02 2015 daviddavid <daviddavid> 1.10-1.mga6
+ Revision: 907787
- new version: 1.10
- update URLs
- add -numpy patch from Fedora to fix test failure

* Thu Oct 08 2015 daviddavid <daviddavid> 1.9.1-2.mga6
+ Revision: 887341
- rebuild for python 3.5
- use new python macros

* Thu Jul 16 2015 daviddavid <daviddavid> 1.9.1-1.mga6
+ Revision: 854605
- new version: 1.9.1
- update new upstream URL
- add some upstream files to avoid downloading the doc files while building
- update BuildRequires and Requires list from main and python3 packages
- add some BuildRequires from doc subpackage on sphinx, sphinx_rtd_theme and numpydoc
- fix Group
- fix duplicate files on html doc
- update file list

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-7.mga5
+ Revision: 743524
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.8.1-6.mga5
+ Revision: 729148
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.8.1-4.mga5
+ Revision: 628843
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.8.1-3.mga4
+ Revision: 543868
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.8.1-2.mga4
+ Revision: 498964
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 09 2013 philippem <philippem> 1.8.1-1.mga4
+ Revision: 476777
- Update to 1.8.1, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.7-3.mga3
+ Revision: 379160
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.7-2.mga3
+ Revision: 324753
- rebuild for Mga3 Beta1

* Sat Aug 25 2012 kamil <kamil> 1.7-1.mga3
+ Revision: 283806
- new version 1.7

* Wed Jul 04 2012 kamil <kamil> 1.6-1.mga3
+ Revision: 267115
- adapt .spec for Mageia
- imported package python-networkx

